<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>OutputJACKFactory</name>
    <message>
        <location filename="../outputjackfactory.cpp" line="30"/>
        <source>JACK Plugin</source>
        <translation>JACK プラグイン</translation>
    </message>
    <message>
        <location filename="../outputjackfactory.cpp" line="53"/>
        <source>About Jack Output Plugin</source>
        <translation>JACK 出力プラグインについて</translation>
    </message>
    <message>
        <location filename="../outputjackfactory.cpp" line="54"/>
        <source>Qmmp Jack Output Plugin</source>
        <translation>QMMP JACK 出力プラグイン</translation>
    </message>
    <message>
        <location filename="../outputjackfactory.cpp" line="55"/>
        <source>Written by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
        <translation>制作: Юрий Журавлёв (Yuriy Zhuravlev) &lt;slalkerg@gmail.com&gt;</translation>
    </message>
</context>
</TS>
